@@ -74,7 +74,7 @@ struct	_GScannerKey
 
 
 /* --- variables --- */
-static GScannerConfig g_scanner_config_template =
+static const GScannerConfig g_scanner_config_template =
 {
   (
    " \t\r\n"
@@ -1705,8 +1705,7 @@ g_scanner_get_token_ll	(GScanner	*scanner,
   
   if (gstring)
     {
-      value.v_string = gstring->str;
-      g_string_free (gstring, FALSE);
+      value.v_string = g_string_free (gstring, FALSE);
       gstring = NULL;
     }
   
